# checked with BV21.4.5 on Mac OS X

import os
from matplotlib.figure import Figure
from matplotlib.backends.backend_agg import FigureCanvasAgg
import numpy as np  # the Python array package
from scipy import ndimage, misc

fig1 = Figure(figsize=(5, 3)) # from Matplotlib
ax1 = fig1.add_subplot(111) # from Matplotlib

def create_fig_dlg(fig, title):    
    canvas = FigureCanvasAgg(fig)
    canvas.print_figure(os.path.join(os.getcwd(), '.matplotlib-for-qt.png')) # current solution: save matplotlib-fig to disk and reload as QImage below
    img = qt.QImage()
    ok = img.load(os.path.join(os.getcwd(), '.matplotlib-for-qt.png'))
    if ok == False:
        return
    dlg = qt.QWidget()
    dlg.setAttribute(55, True) # 55 -> WA_DeleteOnClose
    dlg.setWindowTitle(title)
    box = qt.QVBoxLayout(dlg)
    label = qt.QLabel(dlg)
    label.setContentsMargins(0, 0, 0, 0)
    box.setContentsMargins(0, 0, 0, 0)
    box.addWidget(label)
    pxm = qt.QPixmap()
    pxm.convertFromImage(img)
    label.setPixmap(pxm)
    label.setScaledContents(True)
    return dlg

# get the anatomical BV data
vmrfilename = BrainVoyager.BrowseFile("Please select an VMR File", "*.vmr")
docvmr = BrainVoyager.OpenDocument(vmrfilename)
volumeData = docvmr.GetVolumeDataAsDoubleList()
t1_data1D = np.array(volumeData)                       # convert list (or tuple) to numpy array
t1_data = t1_data1D.reshape(docvmr.DimX, docvmr.DimY, docvmr.DimZ) # reshape 1D to 3D array

# (FMR -> make VTC -> Show VTC Volume (3D Volume Tools) -> Save as secondary VMR)
vmrfilename = BrainVoyager.BrowseFile("Please select the functional volume", "*.vmr")
docvmr2 = BrainVoyager.OpenDocument(vmrfilename)
volumeData2 = docvmr2.GetVolumeDataAsDoubleList()
t2_data1D = np.array(volumeData2)                       # convert list (or tuple) to numpy array
t2_data = t2_data1D.reshape(docvmr.DimX, docvmr.DimY, docvmr.DimZ) # reshape 1D to 3D array

t1_slice = t1_data[:, :, 128]
t1_slice90 = ndimage.rotate(t1_slice, -90, reshape=False)
t2_slice = t2_data[:, :, 128]
t2_slice90 = ndimage.rotate(t2_slice, -90, reshape=False)
ax1.imshow(np.hstack((t1_slice90, t2_slice90))) 
dlg1 = create_fig_dlg(fig1, 'Anatomical and functional data (slice = 128)') # specific for BV21 
dlg1.show() # specific for BV21 